Package: InTAD
Type: Package
Title: Search for correlation between epigenetic signals and gene
        expression in TADs
Version: 1.31.0
Author: Konstantin Okonechnikov, Serap Erkek, Lukas Chavez
Maintainer: Konstantin Okonechnikov <k.okonechnikov@gmail.com>
Description: The package is focused on the detection of correlation between expressed genes and selected epigenomic signals (i.e. enhancers obtained from ChIP-seq data) either within topologically associated domains (TADs) or between chromatin contact loop anchors. Various parameters can be controlled to investigate the influence of external factors and visualization plots are available for each analysis step.  
License: GPL (>=2)
LazyData: TRUE
Depends: R (>= 3.5), methods, S4Vectors, IRanges, GenomicRanges,
        MultiAssayExperiment, SummarizedExperiment,stats
Imports:
        BiocGenerics,Biobase,rtracklayer,parallel,graphics,mclust,qvalue,
        ggplot2,utils,ggpubr
biocViews: Epigenetics, Sequencing, ChIPSeq, RNASeq, HiC,
        GeneExpression,ImmunoOncology
VignetteBuilder: knitr
Suggests: testthat, BiocStyle, knitr, rmarkdown
RoxygenNote: 6.0.1
git_url: https://git.bioconductor.org/packages/InTAD
git_branch: devel
git_last_commit: c1355bb
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-04 23:09:19 UTC; biocbuild
